hist package
============

.. automodule:: hist
   :members:
   :show-inheritance:
   :undoc-members:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   hist.axis
   hist.dask

Submodules
----------

.. toctree::
   :maxdepth: 4

   hist.accumulators
   hist.axestuple
   hist.basehist
   hist.classichist
   hist.hist
   hist.interop
   hist.intervals
   hist.namedhist
   hist.numpy
   hist.plot
   hist.quick_construct
   hist.stack
   hist.storage
   hist.svgplots
   hist.svgutils
   hist.tag
   hist.version
